@@ -135,6 +135,19 @@ export class ConversationServiceUtils {
           return;
         }
 
+        // Check if this is an authentication/subscription error
+        const errorMessage = error instanceof Error ? error.message : String(error);
+        const isAuthError = errorMessage.includes('authentication_error') || 
+                           errorMessage.includes('Invalid API key') ||
+                           (errorMessage.includes('401') && errorMessage.includes('error'));
+        
+        if (isAuthError) {
+          // Don't retry for authentication errors - immediately show subscription card
+          console.log('Authentication error detected - showing subscription card instead of retrying');
+          context.messageComponent.displaySubscriptionCard();
+          return; // Exit early to prevent retry
+        }
+
         // Progressive backoff delays: 5s, 15s, 30s
         const retryDelays = [5, 15, 30];
         const delaySeconds = retryDelays[attempt - 1] || 30;
