@@ -8,6 +8,21 @@ import { AppStateService } from '../../AppState';
 import { CachingService, SETTING_KEYS } from '../../utils/caching';
 import { KernelUtils } from '../../utils/kernelUtils';
 import { DatabaseMetadataCache } from '../../Services/DatabaseMetadataCache';
+import { JupyterAuthService } from '../../Services/JupyterAuthService';
+
+/**
+ * Interface for user profile data
+ */
+export interface IUserProfile {
+  id: string;
+  clerk_id: string;
+  email: string;
+  created_at: string;
+  updated_at: string;
+  subscription_expiry: string | null;
+  subscription_price_id: string | null;
+  subscribed_at: string | null;
+}
 
 /**
  * Interface for the Settings state
@@ -20,6 +35,9 @@ export interface ISettingsState {
   claudeModelId: string;
   claudeModelUrl: string;
   databaseUrl: string;
+  jwtToken: string;
+  isAuthenticated: boolean;
+  userProfile: IUserProfile | null;
 }
 
 /**
@@ -33,12 +51,14 @@ function SettingsContent({
   claudeModelId,
   claudeModelUrl,
   databaseUrl,
+  jwtToken,
+  isAuthenticated,
+  userProfile,
   onTokenModeChange,
   onTabAutocompleteChange,
-  onClaudeApiKeyChange,
-  onClaudeModelIdChange,
-  onClaudeModelUrlChange,
   onDatabaseUrlChange,
+  onLoginClick,
+  onLogoutClick,
   toolService
 }: {
   isVisible: boolean;
@@ -48,18 +68,19 @@ function SettingsContent({
   claudeModelId: string;
   claudeModelUrl: string;
   databaseUrl: string;
+  jwtToken: string;
+  isAuthenticated: boolean;
+  userProfile: IUserProfile | null;
   onTokenModeChange: (enabled: boolean) => void;
   onTabAutocompleteChange: (enabled: boolean) => void;
-  onClaudeApiKeyChange: (value: string) => void;
-  onClaudeModelIdChange: (value: string) => void;
-  onClaudeModelUrlChange: (value: string) => void;
   onDatabaseUrlChange: (value: string) => void;
+  onLoginClick: () => void;
+  onLogoutClick: () => void;
   toolService: ToolService;
 }): JSX.Element | null {
   const [codebaseManager, setCodebaseManager] =
     React.useState<CodebaseManager | null>(null);
   const codebaseContainerRef = React.useRef<HTMLDivElement>(null);
-  const [isApiKeyFocused, setIsApiKeyFocused] = React.useState<boolean>(false);
   const [isDatabaseUrlFocused, setIsDatabaseUrlFocused] =
     React.useState<boolean>(false);
 
@@ -172,134 +193,150 @@ function SettingsContent({
     onTabAutocompleteChange(event.target.checked);
   };
 
+  // Check if user is subscribed
+  const isUserSubscribed = React.useMemo(() => {
+    if (!userProfile?.subscription_expiry) {
+      return false;
+    }
+
+    try {
+      const expiryDate = new Date(userProfile.subscription_expiry);
+      const now = new Date();
+      return expiryDate > now;
+    } catch (error) {
+      console.error('[SettingsWidget] Invalid subscription_expiry date:', error);
+      return false;
+    }
+  }, [userProfile?.subscription_expiry]);
+
   return (
-    <div className="sage-ai-settings-container">
-      <h2 className="sage-ai-settings-title">SignalPilot Settings</h2>
+      <div className="sage-ai-settings-container">
+        <h3 className="sage-ai-settings-title">SignalPilot Settings</h3>
+        
+        {/* Codebase Manager Container */}
+        <div ref={codebaseContainerRef}/>
 
-      {/* Codebase Manager Container */}
-      <div ref={codebaseContainerRef} />
+        {/* Database Configuration */}
+        <div className="sage-ai-config-section">
+          <h5 className="sage-ai-config-title">Database Configuration</h5>
 
-      {/* Claude API Configuration */}
-      <div className="sage-ai-config-section">
-        <h3 className="sage-ai-config-title">API Configuration</h3>
+          <div className="sage-ai-field-container">
+            <label className="sage-ai-field-label">Database URL:</label>
+            <div className="sage-ai-database-input-container">
+              <input
+                  type={isDatabaseUrlFocused ? 'text' : 'password'}
+                  value={databaseUrl}
+                  onChange={e => onDatabaseUrlChange(e.target.value)}
+                  onFocus={() => setIsDatabaseUrlFocused(true)}
+                  onBlur={() => setIsDatabaseUrlFocused(false)}
+                  placeholder="Enter your database URL"
+                  className="sage-ai-field-input sage-ai-database-input"
+              />
+              <button
+                  onClick={handleRefreshMetadata}
+                  disabled={
+                      !databaseUrl || databaseUrl.trim() === '' || isRefreshing
+                  }
+                  className="sage-ai-refresh-button"
+                  title="Refresh database metadata cache"
+              >
+                {isRefreshing ? (
+                    <div className="sage-ai-db-metadata-spinner">
+                      <div className="sage-ai-db-spinner-ring"></div>
+                      <div className="sage-ai-db-spinner-pulse"></div>
+                    </div>
+                ) : (
+                    '↻'
+                )}
+              </button>
+            </div>
 
-        <div className="sage-ai-field-container">
-          <label className="sage-ai-field-label">SignalPilot API Key:</label>
-          <input
-            type={isApiKeyFocused ? 'text' : 'password'}
-            value={claudeApiKey}
-            onChange={e => onClaudeApiKeyChange(e.target.value)}
-            onFocus={() => setIsApiKeyFocused(true)}
-            onBlur={() => setIsApiKeyFocused(false)}
-            placeholder="Enter your SignalPilot API key"
-            className="sage-ai-field-input"
-          />
-        </div>
-
-        <div className="sage-ai-field-container">
-          <label className="sage-ai-field-label">SignalPilot Model ID:</label>
-          <input
-            type="text"
-            value={claudeModelId}
-            onChange={e => onClaudeModelIdChange(e.target.value)}
-            placeholder="claude-sonnet-4-20250514"
-            className="sage-ai-field-input"
-          />
-        </div>
-
-        <div className="sage-ai-field-container">
-          <label className="sage-ai-field-label">SignalPilot Model URL:</label>
-          <input
-            type="text"
-            value={claudeModelUrl}
-            onChange={e => onClaudeModelUrlChange(e.target.value)}
-            placeholder="https://sage.alpinex.ai:8760"
-            className="sage-ai-field-input"
-          />
-        </div>
-      </div>
-
-      {/* Database Configuration */}
-      <div className="sage-ai-config-section">
-        <h3 className="sage-ai-config-title">Database Configuration</h3>
-
-        <div className="sage-ai-field-container">
-          <label className="sage-ai-field-label">Database URL:</label>
-          <div className="sage-ai-database-input-container">
-            <input
-              type={isDatabaseUrlFocused ? 'text' : 'password'}
-              value={databaseUrl}
-              onChange={e => onDatabaseUrlChange(e.target.value)}
-              onFocus={() => setIsDatabaseUrlFocused(true)}
-              onBlur={() => setIsDatabaseUrlFocused(false)}
-              placeholder="Enter your database URL"
-              className="sage-ai-field-input sage-ai-database-input"
-            />
-            <button
-              onClick={handleRefreshMetadata}
-              disabled={
-                !databaseUrl || databaseUrl.trim() === '' || isRefreshing
-              }
-              className="sage-ai-refresh-button"
-              title="Refresh database metadata cache"
+            {/* Cache Status */}
+            <div className="sage-ai-cache-status">
+            <span
+                className={`sage-ai-cache-indicator ${cacheStatus.isCached ? (cacheStatus.isExpired ? 'expired' : 'cached') : 'not-cached'}`}
             >
-              {isRefreshing ? (
-                <div className="sage-ai-db-metadata-spinner">
-                  <div className="sage-ai-db-spinner-ring"></div>
-                  <div className="sage-ai-db-spinner-pulse"></div>
+              {cacheStatus.isCached
+                  ? cacheStatus.isExpired
+                      ? '⚠️'
+                      : '✓'
+                  : '○'}
+            </span>
+              <span className="sage-ai-cache-text">
+              {cacheStatus.isCached
+                  ? `Metadata cached (${formatLastUpdated(cacheStatus.lastUpdated)})${cacheStatus.isExpired ? ' - Expired' : ''}`
+                  : 'No metadata cached'}
+            </span>
+            </div>
+          </div>
+        </div>
+
+        <div className="sage-ai-config-section">
+          <div className="sage-ai-field-container">
+            <div className="sage-ai-auth-buttons">
+              {isAuthenticated ? (
+                <div className="sage-ai-user-info">
+                  <div className="sage-ai-logged-in-as">
+                    <div className="sage-ai-logged-in-label">Logged In As:</div>
+                    <div className="sage-ai-logged-in-email">
+                      {userProfile?.email || 'Loading...'}
+                    </div>
+                  </div>
+                  
+                  {/* Subscription Status Badge */}
+                  {isUserSubscribed && (
+                    <div className="sage-ai-subscription-badge-container">
+                      <span className="sage-ai-tool-call-badge sage-ai-subscription-badge">
+                        ✓ Subscribed
+                      </span>
+                    </div>
+                  )}
+                  
+                  <button
+                      onClick={onLogoutClick}
+                      className="sage-ai-button sage-ai-button-secondary"
+                  >
+                    Logout
+                  </button>
                 </div>
               ) : (
-                '↻'
+                  <button
+                      onClick={onLoginClick}
+                      className="sage-ai-button sage-ai-button-primary"
+                  >
+                    Login
+                  </button>
               )}
-            </button>
-          </div>
-
-          {/* Cache Status */}
-          <div className="sage-ai-cache-status">
-            <span
-              className={`sage-ai-cache-indicator ${cacheStatus.isCached ? (cacheStatus.isExpired ? 'expired' : 'cached') : 'not-cached'}`}
-            >
-              {cacheStatus.isCached
-                ? cacheStatus.isExpired
-                  ? '⚠️'
-                  : '✓'
-                : '○'}
-            </span>
-            <span className="sage-ai-cache-text">
-              {cacheStatus.isCached
-                ? `Metadata cached (${formatLastUpdated(cacheStatus.lastUpdated)})${cacheStatus.isExpired ? ' - Expired' : ''}`
-                : 'No metadata cached'}
-            </span>
+            </div>
           </div>
         </div>
-      </div>
 
-      {/* SignalPilot Token Mode Checkbox */}
-      <div className="sage-token-mode-container">
-        <label className="sage-token-mode-label">
-          <input
-            type="checkbox"
-            checked={sageTokenMode}
-            onChange={handleTokenModeChange}
-            className="sage-token-mode-checkbox"
-          />
-          <span>SignalPilot Token Debug Mode</span>
-        </label>
-      </div>
+        {/* SignalPilot Token Mode Checkbox */}
+        <div className="sage-token-mode-container">
+          <label className="sage-token-mode-label">
+            <input
+                type="checkbox"
+                checked={sageTokenMode}
+                onChange={handleTokenModeChange}
+                className="sage-token-mode-checkbox"
+            />
+            <span>SignalPilot Token Debug Mode</span>
+          </label>
+        </div>
 
-      {/* Tab Autocomplete Checkbox */}
-      <div className="sage-tab-autocomplete-container">
-        <label className="sage-tab-autocomplete-label">
-          <input
-            type="checkbox"
-            checked={tabAutocompleteEnabled}
-            onChange={handleTabAutocompleteChange}
-            className="sage-tab-autocomplete-checkbox"
-          />
-          <span>Enable Tab Autocomplete</span>
-        </label>
+        {/* Tab Autocomplete Checkbox */}
+        <div className="sage-tab-autocomplete-container">
+          <label className="sage-tab-autocomplete-label">
+            <input
+                type="checkbox"
+                checked={tabAutocompleteEnabled}
+                onChange={handleTabAutocompleteChange}
+                className="sage-tab-autocomplete-checkbox"
+            />
+            <span>Enable Tab Autocomplete</span>
+          </label>
+        </div>
       </div>
-    </div>
   );
 }
 
@@ -335,11 +372,17 @@ export class SettingsWidget extends ReactWidget {
       claudeApiKey: '',
       claudeModelId: 'claude-sonnet-4-20250514',
       claudeModelUrl: 'https://sage.alpinex.ai:8760',
-      databaseUrl: ''
+      databaseUrl: '',
+      jwtToken: '',
+      isAuthenticated: false,
+      userProfile: null
     };
 
     // Load settings asynchronously
     this.initializeSettings();
+    
+    // Check for authentication callback
+    this.checkAuthCallback();
   }
 
   /**
@@ -356,9 +399,37 @@ export class SettingsWidget extends ReactWidget {
       await this.loadTabAutocompleteSetting(); // Load tab autocomplete setting
       const tokenMode = SettingsWidget.SAGE_TOKEN_MODE;
 
-      // Update AppState with token mode and tab autocomplete
+      // Update AppState with token mode
       AppStateService.updateSettings({ tokenMode });
+
+      // Check for authentication and use JWT token as API key if available
+      const jwtToken = await JupyterAuthService.getJwtToken();
+      const isAuthenticated = await JupyterAuthService.isAuthenticated();
+      let claudeApiKey = appSettings.claudeApiKey;
+      
+      if (isAuthenticated && jwtToken) {
+        console.log('[SettingsWidget] User is authenticated, using JWT token as Claude API key');
+        claudeApiKey = jwtToken;
+        // IMPORTANT: Do NOT save JWT token to settings registry - only update AppState
+        console.log('[SettingsWidget] JWT token will NOT be saved to settings registry (per requirements)');
+        // Update AppState with JWT token
+        AppStateService.updateClaudeSettings({ claudeApiKey: jwtToken });
+        console.log('[SettingsWidget] JWT token set in AppState as Claude API key');
+      }
+
+      // HARDCODED API CONFIGURATION - Remove user customization per requirements
+      const HARDCODED_MODEL_ID = 'claude-sonnet-4-20250514';
+      const HARDCODED_MODEL_URL = 'https://sage.alpinex.ai:8760';
+      
+      console.log('[SettingsWidget] Using hardcoded API configuration:', {
+        modelId: HARDCODED_MODEL_ID,
+        modelUrl: HARDCODED_MODEL_URL
+      });
+
+      // Update AppState with hardcoded values and tab autocomplete
       AppStateService.updateClaudeSettings({
+        claudeModelId: HARDCODED_MODEL_ID,
+        claudeModelUrl: HARDCODED_MODEL_URL,
         tabAutocompleteEnabled: this._state.tabAutocompleteEnabled
       });
 
@@ -367,12 +438,18 @@ export class SettingsWidget extends ReactWidget {
         isVisible: true,
         sageTokenMode: tokenMode,
         tabAutocompleteEnabled: this._state.tabAutocompleteEnabled,
-        claudeApiKey: appSettings.claudeApiKey,
-        claudeModelId: appSettings.claudeModelId,
-        claudeModelUrl: appSettings.claudeModelUrl,
-        databaseUrl: appSettings.databaseUrl
+        claudeApiKey,
+        claudeModelId: HARDCODED_MODEL_ID,
+        claudeModelUrl: HARDCODED_MODEL_URL,
+        databaseUrl: appSettings.databaseUrl,
+        jwtToken: jwtToken || '',
+        isAuthenticated,
+        userProfile: null
       };
 
+      // Update authentication state
+      await this.updateAuthState();
+
       this.update();
     } catch (error) {
       console.error('Failed to initialize settings:', error);
@@ -399,12 +476,14 @@ export class SettingsWidget extends ReactWidget {
         claudeModelId={this._state.claudeModelId}
         claudeModelUrl={this._state.claudeModelUrl}
         databaseUrl={this._state.databaseUrl}
+        jwtToken={this._state.jwtToken}
+        isAuthenticated={this._state.isAuthenticated}
+        userProfile={this._state.userProfile}
         onTokenModeChange={this.handleTokenModeChange.bind(this)}
         onTabAutocompleteChange={this.handleTabAutocompleteChange.bind(this)}
-        onClaudeApiKeyChange={this.handleClaudeApiKeyChange.bind(this)}
-        onClaudeModelIdChange={this.handleClaudeModelIdChange.bind(this)}
-        onClaudeModelUrlChange={this.handleClaudeModelUrlChange.bind(this)}
         onDatabaseUrlChange={this.handleDatabaseUrlChange.bind(this)}
+        onLoginClick={this.handleLoginClick.bind(this)}
+        onLogoutClick={this.handleLogoutClick.bind(this)}
         toolService={this.toolService}
       />
     );
@@ -493,21 +572,22 @@ export class SettingsWidget extends ReactWidget {
       );
     }
 
-    const claudeModelId = await this.loadSetting(
-      SETTING_KEYS.CLAUDE_MODEL_ID,
-      'claude-sonnet-4-20250514'
-    );
-    const claudeModelUrl = await this.loadSetting(
-      SETTING_KEYS.CLAUDE_MODEL_URL,
-      'https://sage.alpinex.ai:8760'
-    );
+    // HARDCODED API CONFIGURATION - Do not load from settings
+    const HARDCODED_MODEL_ID = 'claude-sonnet-4-20250514';
+    const HARDCODED_MODEL_URL = 'https://sage.alpinex.ai:8760';
+    
+    console.log('[SettingsWidget] Using hardcoded model configuration (ignoring saved settings):', {
+      modelId: HARDCODED_MODEL_ID,
+      modelUrl: HARDCODED_MODEL_URL
+    });
+
     const databaseUrl = await this.loadSetting(SETTING_KEYS.DATABASE_URL, '');
 
-    // Update AppState with loaded settings
+    // Update AppState with loaded settings (hardcoded model values)
     AppStateService.updateClaudeSettings({
       claudeApiKey,
-      claudeModelId,
-      claudeModelUrl,
+      claudeModelId: HARDCODED_MODEL_ID,
+      claudeModelUrl: HARDCODED_MODEL_URL,
       databaseUrl
     });
 
@@ -585,39 +665,6 @@ export class SettingsWidget extends ReactWidget {
   /**
    * Handle Claude model ID change
    */
-  private async handleClaudeModelIdChange(value: string): Promise<void> {
-    await this.saveSetting(SETTING_KEYS.CLAUDE_MODEL_ID, value);
-
-    // Update AppState
-    AppStateService.updateClaudeSettings({ claudeModelId: value });
-
-    this._state = {
-      ...this._state,
-      claudeModelId: value
-    };
-
-    this._stateChanged.emit(this._state);
-    this.update();
-  }
-
-  /**
-   * Handle Claude model URL change
-   */
-  private async handleClaudeModelUrlChange(value: string): Promise<void> {
-    await this.saveSetting(SETTING_KEYS.CLAUDE_MODEL_URL, value);
-
-    // Update AppState
-    AppStateService.updateClaudeSettings({ claudeModelUrl: value });
-
-    this._state = {
-      ...this._state,
-      claudeModelUrl: value
-    };
-
-    this._stateChanged.emit(this._state);
-    this.update();
-  }
-
   /**
    * Handle database URL change
    */
@@ -648,6 +695,145 @@ export class SettingsWidget extends ReactWidget {
     this.update();
   }
 
+  /**
+   * Handle login button click
+   */
+  private async handleLoginClick(): Promise<void> {
+    try {
+      // Open the web app login page
+      JupyterAuthService.openLoginPage();
+    } catch (error) {
+      console.error('Failed to open login page:', error);
+    }
+  }
+
+  /**
+   * Handle logout button click
+   */
+  private async handleLogoutClick(): Promise<void> {
+    try {
+      // First, attempt to revoke the JWT token on the server
+      try {
+        const currentToken = await JupyterAuthService.getJwtToken();
+        if (currentToken) {
+          console.log('[SettingsWidget] Attempting to revoke JWT token on server...');
+          const revoked = await JupyterAuthService.revokeJwtToken(currentToken);
+          if (revoked) {
+            console.log('[SettingsWidget] ✅ JWT token successfully revoked on server');
+          } else {
+            console.warn('[SettingsWidget] ⚠️ Failed to revoke JWT token on server, continuing with local logout');
+          }
+        }
+      } catch (revokeError) {
+        console.error('[SettingsWidget] ❌ Error during token revocation, continuing with local logout:', revokeError);
+      }
+
+      // Always clear the JWT token from StateDB (regardless of revocation success)
+      await JupyterAuthService.clearJwtToken();
+      
+      // Clear the API key completely to invalidate LLM session
+      // Remove from CachingService instead of just setting to empty string
+      await CachingService.removeSetting(SETTING_KEYS.CLAUDE_API_KEY);
+      
+      // Clear from AppStateService to invalidate the current LLM session
+      AppStateService.updateClaudeSettings({ claudeApiKey: '' });
+      
+      // Update state
+      this._state = {
+        ...this._state,
+        jwtToken: '',
+        isAuthenticated: false,
+        claudeApiKey: '',
+        userProfile: null
+      };
+
+      this._stateChanged.emit(this._state);
+      this.update();
+    } catch (error) {
+      console.error('Failed to logout:', error);
+    }
+  }
+
+  /**
+   * Check for authentication callback and update state
+   */
+  private async checkAuthCallback(): Promise<void> {
+    try {
+      // Check if this is an auth callback
+      const wasCallback = await JupyterAuthService.handleAuthCallback();
+      
+      if (wasCallback) {
+        // Update authentication state
+        await this.updateAuthState();
+      }
+    } catch (error) {
+      console.error('Failed to handle auth callback:', error);
+    }
+  }
+
+  /**
+   * Update authentication state from stored JWT
+   */
+  private async updateAuthState(): Promise<void> {
+    try {
+      console.log('[SettingsWidget] Updating authentication state...');
+      const jwtToken = await JupyterAuthService.getJwtToken();
+      const isAuthenticated = await JupyterAuthService.isAuthenticated();
+      
+      console.log('[SettingsWidget] Auth state:', { 
+        hasJWT: !!jwtToken, 
+        jwtLength: jwtToken?.length || 0, 
+        isAuthenticated 
+      });
+      
+      // Get user profile if authenticated
+      let userProfile = null;
+      if (isAuthenticated && jwtToken) {
+        try {
+          console.log('[SettingsWidget] Loading user profile...');
+          userProfile = await JupyterAuthService.getUserProfile();
+          console.log('[SettingsWidget] User profile loaded:', userProfile);
+        } catch (error) {
+          console.error('[SettingsWidget] Failed to load user profile:', error);
+          // Continue without profile data
+        }
+      }
+      
+      // Automatically use JWT token as Claude API key when authenticated
+      let claudeApiKey = this._state.claudeApiKey;
+      if (isAuthenticated && jwtToken) {
+        console.log('[SettingsWidget] User is authenticated, setting JWT as Claude API key');
+        claudeApiKey = jwtToken;
+        // IMPORTANT: Do NOT save JWT token to settings registry - only update AppState
+        console.log('[SettingsWidget] JWT token will NOT be saved to settings registry (per requirements)');
+        // Update AppState with JWT token
+        AppStateService.updateClaudeSettings({ claudeApiKey: jwtToken });
+        console.log('[SettingsWidget] JWT token set in AppState as Claude API key');
+      } else {
+        console.log('[SettingsWidget] User not authenticated or no JWT token available');
+      }
+
+      // HARDCODED API CONFIGURATION - Ensure values remain hardcoded
+      const HARDCODED_MODEL_ID = 'claude-sonnet-4-20250514';
+      const HARDCODED_MODEL_URL = 'https://sage.alpinex.ai:8760';
+      
+      this._state = {
+        ...this._state,
+        jwtToken: jwtToken || '',
+        isAuthenticated,
+        claudeApiKey,
+        claudeModelId: HARDCODED_MODEL_ID,
+        claudeModelUrl: HARDCODED_MODEL_URL,
+        userProfile
+      };
+
+      this._stateChanged.emit(this._state);
+      this.update();
+    } catch (error) {
+      console.error('Failed to update auth state:', error);
+    }
+  }
+
   /**
    * Show the settings widget
    */
