@@ -270,21 +270,6 @@ export class ChatBoxWidget extends Widget {
       'What would you like me to generate or analyze?'
     );
 
-    // Handle keydown events for submission
-    this.chatInput.addEventListener('keydown', (event: Event) => {
-      const keyEvent = event as KeyboardEvent;
-      // Submit on Enter (without shift for newlines)
-      if (
-        keyEvent.key === 'Enter' &&
-        !keyEvent.shiftKey &&
-        this.chatInput.getPlainText().trim() !== '' &&
-        !this.inputManager.getIsProcessingMessage()
-      ) {
-        keyEvent.preventDefault(); // Prevent newline
-        this.inputManager.sendMessage();
-      }
-    });
-
     const newPromptCTA = document.createElement('div');
     newPromptCTA.className = 'sage-ai-new-prompt-cta';
     const text = document.createElement('p');
