@@ -32,4 +32,11 @@ export class NotebookSettingsContainer extends Widget {
     // Set the layout properly
     this.layout = layout;
   }
+
+  /**
+   * Get the settings widget
+   */
+  public getSettingsWidget(): SettingsWidget {
+    return this.settingsWidget;
+  }
 }
