@@ -48,6 +48,10 @@ import {
   setGlobalDiffNavigationWidget,
   setGlobalSnippetCreationWidget
 } from './globalWidgets';
+import { JWTAuthModalService } from './Services/JWTAuthModalService';
+import { JupyterAuthService } from './Services/JupyterAuthService';
+import { JwtTokenDialog, MessageDialog } from './Components/JwtTokenDialog';
+import {SettingsWidget} from "./Components/Settings/SettingsWidget";
 
 export async function activateSage(
   app: JupyterFrontEnd,
@@ -68,6 +72,19 @@ export async function activateSage(
   // Initialize the state database caching service for chat histories
   StateDBCachingService.initialize(db);
 
+  // Initialize JWT authentication immediately on startup (CRITICAL: Do this early!)
+  console.log('[Plugin] Initializing JWT authentication on startup...');
+  try {
+    const jwtInitialized = await JWTAuthModalService.initializeJWTOnStartup();
+    if (jwtInitialized) {
+      console.log('[Plugin] JWT authentication initialized successfully on startup');
+    } else {
+      console.log('[Plugin] No JWT token found during startup initialization');
+    }
+  } catch (error) {
+    console.error('[Plugin] Failed to initialize JWT on startup:', error);
+  }
+
   // Load snippets from StateDB (async, non-blocking)
   AppStateService.loadSnippets().catch(error => {
     console.warn('[Plugin] Failed to load snippets from StateDB:', error);
@@ -598,6 +615,29 @@ export async function activateSage(
   setGlobalSnippetCreationWidget(snippetCreationWidget);
   setGlobalDiffNavigationWidget(diffNavigationWidget);
 
+  // Initialize JWT authentication check - show modal if user is not authenticated
+  const jwtModalService = JWTAuthModalService.getInstance();
+  
+  // Listen for settings widget state changes to detect authentication
+  if (settingsContainer) {
+    const settingsWidget = settingsContainer.getSettingsWidget();
+    settingsWidget.stateChanged.connect(() => {
+      const state = settingsWidget.getState();
+      if (state.isAuthenticated) {
+        // User has authenticated, hide the JWT modal if it's showing
+        jwtModalService.checkAndHideIfAuthenticated();
+      }
+    });
+  }
+  
+  // Check authentication status after initialization
+  void app.restored.then(async () => {
+    // Wait a bit for everything to settle, then check authentication
+    setTimeout(async () => {
+      await jwtModalService.showIfNeeded();
+    }, 1000);
+  });
+
   // Register DiffNavigationWidget with AppStateService
   if (diffNavigationWidget) {
     AppStateService.setDiffNavigationWidget(diffNavigationWidget);
@@ -820,6 +860,52 @@ export async function activateSage(
         dispose: () => kernelExecutionListener.dispose(),
         reinitialize: () => kernelExecutionListener.initialize(notebooks)
       };
+
+      // Add login success modal debugging functions
+      (window as any).debugLoginSuccess = {
+        show: async () => {
+          try {
+            const { LoginSuccessModalService } = await import('./Services/LoginSuccessModalService');
+            LoginSuccessModalService.debugShow();
+            console.log('✅ Login success modal triggered from debug');
+          } catch (error) {
+            console.error('❌ Failed to show login success modal:', error);
+          }
+        },
+        getDebugInfo: async () => {
+          try {
+            const { LoginSuccessModalService } = await import('./Services/LoginSuccessModalService');
+            const instance = LoginSuccessModalService.getInstance();
+            return instance.getDebugInfo();
+          } catch (error) {
+            console.error('❌ Failed to get debug info:', error);
+            return null;
+          }
+        }
+      };
+
+      // Add JWT auth modal debugging functions
+      (window as any).debugJWTAuth = {
+        show: () => {
+          jwtModalService.show();
+          console.log('✅ JWT auth modal shown from debug');
+        },
+        hide: () => {
+          jwtModalService.hide();
+          console.log('✅ JWT auth modal hidden from debug');
+        },
+        forceShow: () => {
+          jwtModalService.forceShow();
+          console.log('✅ JWT auth modal force shown from debug');
+        },
+        checkAndHide: async () => {
+          await jwtModalService.checkAndHideIfAuthenticated();
+          console.log('✅ JWT auth modal check and hide completed');
+        },
+        getDebugInfo: async () => {
+          return await jwtModalService.getDebugInfo();
+        }
+      };
     }
   });
 
@@ -961,5 +1047,48 @@ export async function activateSage(
   });
 
   palette.addItem({ command: snippetCommandId, category: 'SignalPilot AI' });
+
+  // Add command to activate test mode - allows setting JWT token directly
+  const testModeCommandId = 'signalpilot-ai-internal:activate-test-mode';
+
+  commands.addCommand(testModeCommandId, {
+    label: 'Activate Test Mode (Set JWT Token)',
+    execute: async () => {
+      try {
+        const jwtDialog = new JwtTokenDialog();
+        const result = await jwtDialog.showDialog();
+
+        if (result.accepted && result.value) {
+          console.log('[Test Mode] Setting JWT token...');
+          await JupyterAuthService.storeJwtToken(result.value);
+          AppStateService.updateClaudeSettings({ claudeApiKey: result.value });
+
+          console.log('[Test Mode] JWT token set successfully');
+          
+          // Show success message
+          await MessageDialog.showMessage(
+            'Test Mode',
+            'JWT token has been set successfully in the state database.'
+          );
+        } else {
+          console.log('[Test Mode] JWT token setting cancelled');
+        }
+      } catch (error) {
+        console.error('[Test Mode] Failed to set JWT token:', error);
+        
+        const errorMessage = error instanceof Error ? error.message : String(error);
+        
+        // Show error message
+        await MessageDialog.showMessage(
+          'Test Mode - Error',
+          `Failed to set JWT token: ${errorMessage}`,
+          true
+        );
+      }
+    }
+  });
+
+  palette.addItem({ command: testModeCommandId, category: 'SignalPilot AI' });
+
   return;
 }
